# moro

A Python library for kinematic and dynamic modeling of robots.

# Installation

Using `pip` to install latest version in PyPI:

```
pip install moro
```

Or from this repo:

```
pip install https://github.com/numython-rd/moro.git
```

# Documentation and examples

Documentation is available in [https://numython-rd.github.io/moro/](https://numython-rd.github.io/moro/). 

Also, Jupyter Notebooks are available in: [https://nbviewer.jupyter.org/github/numython-rd/moro/tree/master/examples/nbooks/](https://nbviewer.jupyter.org/github/numython-rd/moro/tree/master/examples/nbooks/)


# Bugs

Please report any bugs that you find, use the issue tracker: [https://github.com/numython-rd/moro/issues](https://github.com/numython-rd/moro/issues)

# Roadmap

Roadmap of moro: https://github.com/numython-rd/moro/wiki/Roadmap